@@ -10,14 +10,14 @@
 #ifndef _FILE_H
 #define _FILE_H
 
+#include "config.h"
 #include "inset.h"
 #include "layout.h"
-#include "config.h"
 #include "lyxtext.h"
 
 enum { NO_LOGFILE=-1, NO_OUPUT, RUN_OK };
 
-typedef struct TeXErrors{
+struct TeXErrors{
   int status;
   int number_of_errors;
   TeXErrors() {
