@@ -6,7 +6,6 @@
 #ifndef _INTL_H
 #define _INTL_H
 
-#include "config.h"
 #include "lyxtext.h"
 
 #define DEFCHSET "iso8859-1"	// default character set
@@ -14,13 +13,13 @@
 void MenuKeymap();
 	/* show key mapping dialog */
 
-int SelectKeyMap(char *keyfile);
+//int SelectKeyMap(char *keyfile);
 	/* load keyboard map from keyfile, return 0 on success, -1 else */
 
-void ChangeKeymap(char *keyfile, bool on, bool warn, int lngidx);
+//void ChangeKeymap(char *keyfile, bool on, bool warn, int lngidx);
 	/* change keymap, if possible */
 
-int SelectCharset(char *code);
+//int SelectCharset(char *code);
 	/* select charset to convert symbols to: 0-7-bit ascii (default),
 	   1-10-ISOLatin-xx */
 	/* NOT SUPPORTED YET */
@@ -30,8 +29,9 @@ void KeyMapPrim();
 void KeyMapSec();
 void ToggleKeyMap();
 	/* turn on/off key mappings, status in keymapon */
-
-void Translate(char *instr, char *outstr);
+void setPrimary(char*);
+void setSecondary(char*);
+//void Translate(char *instr, char *outstr);
 	/* translate instr and write to outstr, if translations are on */
 	/* provide big enough buffer !!! Ie, 128 bytes */
 
@@ -41,12 +41,12 @@ void TranslateAndInsert(char c, LyXText *text);
 void InitKeyMapper();
 	/* initialize key mapper */
 
-extern bool keymapon;	/* disabled by default */
-extern char *chsetcode;	/* default to iso8859-1 */
+//extern bool keymapon;	/* disabled by default */
+//extern char *chsetcode;	/* default to iso8859-1 */
 
 /* private functions: */
 
-void ParseKeymapFile(FILE *f, int depth);
-void FreeKeymap();
+// void ParseKeymapFile(FILE *f, int depth);
+// void FreeKeymap();
 
 #endif
