@@ -2,7 +2,7 @@
 #ifndef _MINIBUFFER_H
 #define _MINIBUFFER_H
 
-#include <forms.h>
+#include "forms.h"
 
 class MiniBuffer {
 private:
@@ -38,6 +38,8 @@ public:
 	void ExecCommand();
        void Store(); // allows to store and reset the contents one time. Usefull for status messages like "load font" (Matthias)
        void Reset();
+       void Activate();
+       void Deactivate();
 };
 
 extern MiniBuffer minibuffer;
