@@ -12,7 +12,7 @@
 
 #include "lyxfont.h"
 #include "definitions.h"
-#include <forms.h>
+#include "forms.h"
 
 /* table for all the fonts
  * family        series          shape       size - zoom  (zoom from 1 to 4)
